@@ -1,7 +1,7 @@
 // qtractorAudioBuffer.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -191,16 +191,23 @@ public:
 	void setPeakFile(qtractorAudioPeakFile *pPeakFile);
 	qtractorAudioPeakFile *peakFile() const;
 
-	// Sample-rate converter type accessor (global option).
-	static void setResampleType(int iResampleType);
-	static int resampleType();
+	// WSOLA time-stretch modes (local options).
+	void setWsolaTimeStretch(bool bWsolaTimeStretch);
+	bool isWsolaTimeStretch() const;
+
+	void setWsolaQuickSeek(bool bWsolaQuickSeek);
+	bool isWsolaQuickSeek() const;
 
 	// WSOLA time-stretch modes (global options).
-	static void setWsolaTimeStretch(bool bWsolaTimeStretch);
-	static bool isWsolaTimeStretch();
+	static void setDefaultWsolaTimeStretch(bool bWsolaTimeStretch);
+	static bool isDefaultWsolaTimeStretch();
 
-	static void setWsolaQuickSeek(bool bWsolaQuickSeek);
-	static bool isWsolaQuickSeek();
+	static void setDefaultWsolaQuickSeek(bool bWsolaQuickSeek);
+	static bool isDefaultWsolaQuickSeek();
+
+	// Sample-rate converter type accessor (global option).
+	static void setDefaultResampleType(int iResampleType);
+	static int defaultResampleType();
 
 protected:
 
@@ -288,12 +295,16 @@ private:
 
 	qtractorAudioPeakFile *m_pPeakFile;
 
-	// Sample-rate converter type global option.
-	static int     g_iResampleType;
+	// Time-stretch mode local options.
+	bool           m_bWsolaTimeStretch;
+	bool           m_bWsolaQuickSeek;
 
 	// Time-stretch mode global options.
-	static bool    g_bWsolaTimeStretch;
-	static bool    g_bWsolaQuickSeek;
+	static bool    g_bDefaultWsolaTimeStretch;
+	static bool    g_bDefaultWsolaQuickSeek;
+
+	// Sample-rate converter type global option.
+	static int     g_iDefaultResampleType;
 };
 
 
