@@ -1,7 +1,7 @@
 // qtractorClipCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -316,6 +316,18 @@ void qtractorClipCommand::resetClip ( qtractorClip *pClip )
 }
 
 
+void qtractorClipCommand::wsolaClip ( qtractorClip *pClip,
+	bool bWsolaTimeStretch, bool bWsolaQuickSeek )
+{
+	Item *pItem = new Item(WsolaClip, pClip, pClip->track());
+	pItem->wsolaTimeStretch = bWsolaTimeStretch;
+	pItem->wsolaQuickSeek = bWsolaQuickSeek;
+	m_items.append(pItem);
+
+	reopenClip(pClip, true);
+}
+
+
 void qtractorClipCommand::reopenClip ( qtractorClip *pClip, bool bClose )
 {
 	QHash<qtractorClip *, bool>::ConstIterator iter
@@ -439,6 +451,10 @@ bool qtractorClipCommand::addClipRecord (
 	else
 	addClipRecordTake(pTrack, pClip, iClipStart, iClipOffset, iClipLength);
 
+	// Make sure this brand new filename is not reused!
+	// (see qtractroSession::createFilePath()...)
+	pSession->releaseFilePath(pClip->filename());
+
 	// Can get rid of the recorded clip.
 	pTrack->setClipRecord(NULL);
 
@@ -793,6 +809,20 @@ bool qtractorClipCommand::execute ( bool bRedo )
 				iClipStartTime, iClipStartTime + iClipLengthTime);
 			break;
 		}
+		case WsolaClip: {
+			qtractorAudioClip *pAudioClip = NULL;
+			if (pTrack->trackType() == qtractorTrack::Audio)
+				pAudioClip = static_cast<qtractorAudioClip *> (pClip);
+			if (pAudioClip) {
+				const bool bOldWsolaTimeStretch = pAudioClip->isWsolaTimeStretch();
+				const bool bOldWsolaQuickSeek = pAudioClip->isWsolaQuickSeek();
+				pAudioClip->setWsolaTimeStretch(pItem->wsolaTimeStretch);
+				pAudioClip->setWsolaQuickSeek(pItem->wsolaQuickSeek);
+				pItem->wsolaTimeStretch = bOldWsolaTimeStretch;
+				pItem->wsolaQuickSeek = bOldWsolaQuickSeek;
+			}
+			break;
+		}
 		default:
 			break;
 		}
