@@ -255,7 +255,7 @@ public:
 protected:
 
 	// Snap to minimum distance frame.
-	bool isMinFrameDist(Node *pNode, unsigned long iFrame) const;
+	bool isMinFrameDist(Node *pNode, unsigned long iFrame, float fValue) const;
 
 	// Node interpolation coefficients updater.
 	void updateNode(Node *pNode);
@@ -610,7 +610,7 @@ public:
 	}
 
 	// Signal/slot notifier accessor.
-	qtractorCurveListProxy *proxy()
+	const qtractorCurveListProxy *proxy() const
 		{ return &m_proxy; }
 
 	// Signal/slot notification.
