@@ -1,7 +1,7 @@
 // qtractorInstrumentForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -218,13 +218,16 @@ void qtractorInstrumentForm::importSlot (void)
 	QStringList files;
 
 	const QString  sExt("ins");
-	const QString& sTitle  = tr("Import Instrument Files") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = tr("Instrument files (*.%1 *.sf2 *.midnam)").arg(sExt);
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to open...
+	const QString& sTitle
+		= tr("Import Instrument Files") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= tr("Instrument files (*.%1 *.sf2 *.midnam)").arg(sExt);
+
 	QFileDialog::Options options = 0;
 	if (pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to open...
 	files = QFileDialog::getOpenFileNames(this,
 		sTitle, pOptions->sInstrumentDir, sFilter, NULL, options);
 #else
@@ -240,8 +243,7 @@ void qtractorInstrumentForm::importSlot (void)
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sInstrumentDir));
 	fileDialog.setSidebarUrls(urls);
-	if (pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		files = fileDialog.selectedFiles();
@@ -376,13 +378,16 @@ void qtractorInstrumentForm::exportSlot (void)
 	QString sPath;
 
 	const QString  sExt("ins");
-	const QString& sTitle  = tr("Export Instrument File") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = tr("Instrument files (*.%1)").arg(sExt);
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to open...
+	const QString& sTitle
+		= tr("Export Instrument File") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= tr("Instrument files (*.%1)").arg(sExt);
+
 	QFileDialog::Options options = 0;
 	if (pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to open...
 	sPath = QFileDialog::getSaveFileName(this,
 		sTitle, pOptions->sInstrumentDir, sFilter, NULL, options);
 #else
@@ -398,8 +403,7 @@ void qtractorInstrumentForm::exportSlot (void)
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sInstrumentDir));
 	fileDialog.setSidebarUrls(urls);
-	if (pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		sPath = fileDialog.selectedFiles().first();
