@@ -25,14 +25,19 @@
 
 #include <math.h>
 
-// Possible cube root optimization.
+// Ref. P.448. Approximate cube root of an IEEE float
+// Hacker's Delight (2nd Edition), by Henry S. Warren
+// http://www.hackersdelight.org/hdcodetxt/acbrt.c.txt
+//
 static inline float cbrtf2 ( float x )
 {
-#if 0//ifdef CONFIG_FLOAT32
+#ifdef CONFIG_FLOAT32_NOP
 	// Avoid strict-aliasing optimization (gcc -O2).
 	union { float f; int i; } u;
 	u.f = x;
-	u.i = (u.i / 3) + 710235478; // HACK: 709621077 for cbrtf2(1)=1
+	u.i  = (u.i >> 4) + (u.i >> 2);
+	u.i += (u.i >> 4);
+	u.i += 0x2a6497f8;
 	return u.f;
 #else
 	return ::cbrtf(x);
@@ -106,7 +111,8 @@ void qtractorMidiControlObserver::setMidiValue ( unsigned short iValue )
 	}
 
 	bool bSync = (m_bHook || !qtractorObserver::isDecimal());
-
+	if (!bSync)
+		bSync = m_bMidiSync;
 	if (!bSync) {
 		const float v0 = m_fMidiValue;
 		const float v1 = qtractorObserver::value();
@@ -116,7 +122,7 @@ void qtractorMidiControlObserver::setMidiValue ( unsigned short iValue )
 			 bSync = true;
 	#else
 		const float d1 = (v1 - fValue);
-		const float d2 = (m_bMidiSync ? (v1 - v0) : d1) * d1;
+		const float d2 = (v1 - v0) * d1;
 		bSync = (d2 < 0.001f);
 	#endif
 		if (bSync)
