@@ -1,7 +1,7 @@
 // qtractorMidiEditorForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -692,6 +692,9 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 		m_pEventTypeComboBox->setCurrentIndex(0);
 	//	eventTypeChanged(0);
 	}
+
+	// HACK: Some explicit focus immediately...
+	m_pMidiEditor->editView()->setFocus();
 }
 
 
@@ -742,15 +745,21 @@ bool qtractorMidiEditorForm::queryClose (void)
 
 	// Are we dirty enough to prompt it?
 	if (m_iDirtyCount > 0) {
-		switch (querySave(filename())) {
-		case QMessageBox::Save:
+		if (isVisible()) {
+			// Currently visible: save conditionally...
+			switch (querySave(filename(), this)) {
+			case QMessageBox::Save:
+				bQueryClose = saveClipFile(false);
+				// Fall thru....
+			case QMessageBox::Discard:
+				break;
+			default:    // Cancel.
+				bQueryClose = false;
+				break;
+			}
+		} else {
+			// Not currently visible: save unconditionally...
 			bQueryClose = saveClipFile(false);
-			// Fall thru....
-		case QMessageBox::Discard:
-			break;
-		default:    // Cancel.
-			bQueryClose = false;
-			break;
 		}
 	}
 
@@ -759,10 +768,13 @@ bool qtractorMidiEditorForm::queryClose (void)
 
 
 // Save(as) warning message box.
-int qtractorMidiEditorForm::querySave ( const QString& sFilename )
+int qtractorMidiEditorForm::querySave (
+	const QString& sFilename, QWidget *pParent )
 {
-	return (QMessageBox::warning(
-		qtractorMainForm::getInstance(),
+	if (pParent == NULL)
+		pParent = qtractorMainForm::getInstance();
+
+	return (QMessageBox::warning(pParent,
 		tr("Warning") + " - " QTRACTOR_TITLE,
 		tr("The current MIDI clip has been changed:\n\n"
 		"\"%1\"\n\n"
@@ -1021,14 +1033,16 @@ bool qtractorMidiEditorForm::saveClipFile ( bool bPrompt )
 	if (bPrompt) {
 		// If none is given, assume default directory.
 		const QString sExt("mid");
-		const QString& sTitle  = tr("Save MIDI Clip") + " - " QTRACTOR_TITLE;
-		const QString& sFilter = tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt);
-	#if 1//QT_VERSION < 0x040400
-		// Ask for the filenames to open...
+		const QString& sTitle
+			= tr("Save MIDI Clip") + " - " QTRACTOR_TITLE;
+		const QString& sFilter
+			= tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt);
 		QFileDialog::Options options = 0;
 		qtractorOptions *pOptions = qtractorOptions::getInstance();
 		if (pOptions && pOptions->bDontUseNativeDialogs)
 			options |= QFileDialog::DontUseNativeDialog;
+	#if 1//QT_VERSION < 0x040400
+		// Ask for the filenames to open...
 		sFilename = QFileDialog::getSaveFileName(this,
 			sTitle, sFilename, sFilter, NULL, options);
 	#else
@@ -1040,15 +1054,13 @@ bool qtractorMidiEditorForm::saveClipFile ( bool bPrompt )
 		fileDialog.setFileMode(QFileDialog::AnyFile);
 		fileDialog.setDefaultSuffix(sExt);
 		// Stuff sidebar...
-		qtractorOptions *pOptions = qtractorOptions::getInstance();
 		if (pOptions) {
 			QList<QUrl> urls(fileDialog.sidebarUrls());
 			urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 			urls.append(QUrl::fromLocalFile(pOptions->sMidiDir));
 			fileDialog.setSidebarUrls(urls);
-			if (pOptions->bDontUseNativeDialogs)
-				fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 		}
+		fileDialog.setOptions(options);
 		// Show dialog...
 		if (fileDialog.exec())
 			sFilename = fileDialog.selectedFiles().first();
@@ -2147,3 +2159,4 @@ void qtractorMidiEditorForm::contentsChanged ( qtractorMidiEditor *pMidiEditor )
 
 
 // end of qtractorMidiEditorForm.cpp
+
