@@ -1,7 +1,7 @@
 // qtractorOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -220,6 +220,10 @@ public:
 	// Plug-in GUI options.
 	bool bOpenEditor;
 
+	// Whether to ask for plug-in editor (GUI)
+	// when more than one is available.
+	bool bQueryEditorType;
+
 	// VST dummy plugin scan option.
 	bool bDummyVstScan;
 
@@ -333,3 +337,4 @@ private:
 
 
 // end of qtractorOptions.h
+
