@@ -1,7 +1,7 @@
 // qtractorOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -450,6 +450,9 @@ qtractorOptionsForm::qtractorOptionsForm (
 	QObject::connect(m_ui.OpenEditorCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(changed()));
+	QObject::connect(m_ui.QueryEditorTypeCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(changed()));
 	QObject::connect(m_ui.DummyVstScanCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(pluginPathsChanged()));
@@ -708,6 +711,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	m_ui.AudioOutputBusCheckBox->setChecked(m_pOptions->bAudioOutputBus);
 	m_ui.AudioOutputAutoConnectCheckBox->setChecked(m_pOptions->bAudioOutputAutoConnect);
 	m_ui.OpenEditorCheckBox->setChecked(m_pOptions->bOpenEditor);
+	m_ui.QueryEditorTypeCheckBox->setChecked(m_pOptions->bQueryEditorType);
 	m_ui.DummyVstScanCheckBox->setChecked(m_pOptions->bDummyVstScan);
 	m_ui.Lv2DynManifestCheckBox->setChecked(m_pOptions->bLv2DynManifest);
 	m_ui.SaveCurve14bitCheckBox->setChecked(m_pOptions->bSaveCurve14bit);
@@ -817,6 +821,7 @@ void qtractorOptionsForm::accept (void)
 		m_pOptions->bAudioOutputBus      = m_ui.AudioOutputBusCheckBox->isChecked();
 		m_pOptions->bAudioOutputAutoConnect = m_ui.AudioOutputAutoConnectCheckBox->isChecked();
 		m_pOptions->bOpenEditor          = m_ui.OpenEditorCheckBox->isChecked();
+		m_pOptions->bQueryEditorType     = m_ui.QueryEditorTypeCheckBox->isChecked();
 		m_pOptions->bDummyVstScan        = m_ui.DummyVstScanCheckBox->isChecked();
 		m_pOptions->bLv2DynManifest      = m_ui.Lv2DynManifestCheckBox->isChecked();
 		m_pOptions->bSaveCurve14bit      = m_ui.SaveCurve14bitCheckBox->isChecked();
@@ -1042,9 +1047,15 @@ void qtractorOptionsForm::changeMidiMeterColor ( const QString& sColor )
 // Audio meter color selection.
 void qtractorOptionsForm::chooseAudioMeterColor (void)
 {
+	const QString& sTitle
+		= tr("Audio Meter Color") + " - " QTRACTOR_TITLE;
+
+	QColorDialog::ColorDialogOptions options = 0;
+	if (m_pOptions && m_pOptions->bDontUseNativeDialogs)
+		options |= QColorDialog::DontUseNativeDialog;
+
 	const QColor& color = QColorDialog::getColor(
-		QColor(m_ui.AudioMeterColorLineEdit->text()), this,
-		tr("Audio Meter Color") + " - " QTRACTOR_TITLE);
+		QColor(m_ui.AudioMeterColorLineEdit->text()), this, sTitle, options);
 
 	if (color.isValid())
 		m_ui.AudioMeterColorLineEdit->setText(color.name());
@@ -1054,9 +1065,15 @@ void qtractorOptionsForm::chooseAudioMeterColor (void)
 // Midi meter color selection.
 void qtractorOptionsForm::chooseMidiMeterColor (void)
 {
+	const QString& sTitle
+		= tr("MIDI Meter Color") + " - " QTRACTOR_TITLE;
+
+	QColorDialog::ColorDialogOptions options = 0;
+	if (m_pOptions && m_pOptions->bDontUseNativeDialogs)
+		options |= QColorDialog::DontUseNativeDialog;
+
 	const QColor& color = QColorDialog::getColor(
-		QColor(m_ui.MidiMeterColorLineEdit->text()), this,
-		tr("MIDI Meter Color") + " - " QTRACTOR_TITLE);
+		QColor(m_ui.MidiMeterColorLineEdit->text()), this, sTitle, options);
 
 	if (color.isValid())
 		m_ui.MidiMeterColorLineEdit->setText(color.name());
@@ -1140,13 +1157,15 @@ void qtractorOptionsForm::choosePluginPath (void)
 {
 	QString sPluginPath;
 
-	const QString& sTitle = tr("Plug-in Directory") + " - " QTRACTOR_TITLE;
-#if 1//QT_VERSION < 0x040400
-	// Ask for the directory...
+	const QString& sTitle
+		= tr("Plug-in Directory") + " - " QTRACTOR_TITLE;
+
 	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
 	if (m_pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
-    sPluginPath = QFileDialog::getExistingDirectory(this,
+#if 1//QT_VERSION < 0x040400
+	// Ask for the directory...
+	sPluginPath = QFileDialog::getExistingDirectory(this,
 		sTitle, m_ui.PluginPathComboBox->currentText(), options);
 #else
 	// Construct open-directory dialog...
@@ -1159,8 +1178,7 @@ void qtractorOptionsForm::choosePluginPath (void)
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(m_pOptions->sSessionDir));
 	fileDialog.setSidebarUrls(urls);
-	if (m_pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		sPluginPath = fileDialog.selectedFiles().first();
@@ -1376,12 +1394,14 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 	if (sLv2PresetDir.isEmpty())
 		sLv2PresetDir = QDir::homePath() + QDir::separator() + ".lv2";
 
-	const QString& sTitle = tr("LV2 Presets Directory") + " - " QTRACTOR_TITLE;
-#if 1// QT_VERSION < 0x040400
-	// Ask for the directory...
+	const QString& sTitle
+		= tr("LV2 Presets Directory") + " - " QTRACTOR_TITLE;
+
 	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
 	if (m_pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1// QT_VERSION < 0x040400
+	// Ask for the directory...
 	sLv2PresetDir = QFileDialog::getExistingDirectory(this,
 		sTitle, sLv2PresetDir, options);
 #else
@@ -1395,8 +1415,7 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(m_pOptions->sLv2PresetDir));
 	fileDialog.setSidebarUrls(urls);
-	if (m_pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		sLv2PresetDir = fileDialog.selectedFiles().first();
@@ -1414,13 +1433,20 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 // The messages font selection dialog.
 void qtractorOptionsForm::chooseMessagesFont (void)
 {
-	bool  bOk  = false;
-	QFont font = QFontDialog::getFont(&bOk,
-		m_ui.MessagesFontTextLabel->font(), this);
+	const QString& sTitle
+		= tr("Messages Font") + " - " QTRACTOR_TITLE;
+
+	QFontDialog::FontDialogOptions options = 0;
+	if (m_pOptions->bDontUseNativeDialogs)
+		options |= QFontDialog::DontUseNativeDialog;
+
+	bool bOk = false;
+	const QFont font = QFontDialog::getFont(&bOk,
+		m_ui.MessagesFontTextLabel->font(), this, sTitle, options);
 	if (bOk) {
 		m_ui.MessagesFontTextLabel->setFont(font);
 		m_ui.MessagesFontTextLabel->setText(
-			font.family() + " " + QString::number(font.pointSize()));
+			font.family() + ' ' + QString::number(font.pointSize()));
 		changed();
 	}
 }
@@ -1432,13 +1458,16 @@ void qtractorOptionsForm::chooseMessagesLogPath (void)
 	QString sFilename;
 
 	const QString  sExt("log");
-	const QString& sTitle  = tr("Messages Log") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = tr("Log files (*.%1)").arg(sExt); 
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to open...
+	const QString& sTitle
+		= tr("Messages Log") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= tr("Log files (*.%1)").arg(sExt); 
+
 	QFileDialog::Options options = 0;
 	if (m_pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to open...
 	sFilename = QFileDialog::getSaveFileName(this,
 		sTitle, m_ui.MessagesLogPathComboBox->currentText(), sFilter, NULL, options);
 #else
@@ -1449,8 +1478,7 @@ void qtractorOptionsForm::chooseMessagesLogPath (void)
 	fileDialog.setAcceptMode(QFileDialog::AcceptSave);
 	fileDialog.setFileMode(QFileDialog::AnyFile);
 	fileDialog.setDefaultSuffix(sExt);
-	if (m_pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
@@ -1470,13 +1498,16 @@ void qtractorOptionsForm::chooseSessionTemplatePath (void)
 	QString sFilename;
 
 	const QString  sExt("qtt");
-	const QString& sTitle  = tr("Session Template") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = tr("Session template files (*.qtr *.qts *.%1)").arg(sExt); 
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to open...
+	const QString& sTitle
+		= tr("Session Template") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= tr("Session template files (*.qtr *.qts *.%1)").arg(sExt);
+
 	QFileDialog::Options options = 0;
 	if (m_pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to open...
 	sFilename = QFileDialog::getOpenFileName(this,
 		sTitle, m_ui.SessionTemplatePathComboBox->currentText(), sFilter, NULL, options);
 #else
@@ -1491,8 +1522,7 @@ void qtractorOptionsForm::chooseSessionTemplatePath (void)
 	QList<QUrl> urls(fileDialog.sidebarUrls());
 	urls.append(QUrl::fromLocalFile(m_pOptions->sSessionDir));
 	fileDialog.setSidebarUrls(urls);
-	if (m_pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
@@ -1628,11 +1658,11 @@ QString qtractorOptionsForm::getOpenAudioFileName (
 {
 	QString sAudioFile;
 
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to open...
 	QFileDialog::Options options = 0;
 	if (m_pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to open...
 	sAudioFile = QFileDialog::getOpenFileName(this,
 		sTitle, sFilename, qtractorAudioFileFactory::filters(), NULL, options);
 #else
@@ -1648,8 +1678,7 @@ QString qtractorOptionsForm::getOpenAudioFileName (
 	urls.append(QUrl::fromLocalFile(m_pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(m_pOptions->sAudioDir));
 	fileDialog.setSidebarUrls(urls);
-	if (m_pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		sAudioFile = fileDialog.selectedFiles().first();
