@@ -1,7 +1,7 @@
 // qtractorPlugin.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -242,7 +242,7 @@ qtractorPlugin::qtractorPlugin (
 	qtractorPluginList *pList, qtractorPluginType *pType )
 	: m_pList(pList), m_pType(pType), m_iUniqueID(0), m_iInstances(0),
 		m_bActivated(false), m_activateObserver(this),
-		m_iActivateSubjectIndex(0), m_pForm(NULL),
+		m_iActivateSubjectIndex(0), m_pForm(NULL), m_iEditorType(-1),
 		m_iDirectAccessParamIndex(-1)
 {
 	// Acquire a local unique id in chain...
@@ -787,7 +787,7 @@ qtractorPluginParam *qtractorPlugin::findParam ( unsigned long iIndex ) const
 
 qtractorPluginParam *qtractorPlugin::findParamName ( const QString& sName ) const
 {
-	return m_paramNames.value(sName);
+	return m_paramNames.value(sName, NULL);
 }
 
 
@@ -1111,6 +1111,7 @@ void qtractorPlugin::saveCurveFile ( qtractorDocument *pDocument,
 	pCurveFile->setBaseDir(pSession->sessionDir());
 
 	unsigned short iParam = 0;
+	unsigned long iActivateSubjectIndex = 0;
 	Params::ConstIterator param = m_params.constBegin();
 	const Params::ConstIterator param_end = m_params.constEnd();
 	for ( ; param != param_end; ++param) {
@@ -1142,11 +1143,14 @@ void qtractorPlugin::saveCurveFile ( qtractorDocument *pDocument,
 			pCurveFile->addItem(pCurveItem);
 			++iParam;
 		}
+		if (iActivateSubjectIndex < pParam->index())
+			iActivateSubjectIndex = pParam->index();
 	}
 
-	// Activate subject curve
+	// Activate subject curve...
 	qtractorCurve *pCurve = activateSubject()->curve();
 	if (pCurve) {
+		setActivateSubjectIndex(iActivateSubjectIndex + 1); // hack up!
 		qtractorCurveFile::Item *pCurveItem = new qtractorCurveFile::Item;
 		pCurveItem->name = pCurve->subject()->name();
 		pCurveItem->index = activateSubjectIndex();
@@ -1175,8 +1179,7 @@ void qtractorPlugin::saveCurveFile ( qtractorDocument *pDocument,
 	sBaseName += '_';
 	sBaseName += QString::number(uniqueID(), 16);
 	sBaseName += "_curve";
-//	int iClipNo = (pCurveFile->filename().isEmpty() ? 0 : 1);
-	pCurveFile->setFilename(pSession->createFilePath(sBaseName, "mid", 1));
+	pCurveFile->setFilename(pSession->createFilePath(sBaseName, "mid"));
 
 	pCurveFile->save(pDocument, pElement, pSession->timeScale());
 }
@@ -1200,11 +1203,18 @@ void qtractorPlugin::applyCurveFile ( qtractorCurveFile *pCurveFile )
 
 	pCurveFile->setBaseDir(pSession->sessionDir());
 
+	qtractorSubject *pActivateSubject = activateSubject();
+	unsigned long iActivateSubjectIndex = activateSubjectIndex();
+
 	QListIterator<qtractorCurveFile::Item *> iter(pCurveFile->items());
 	while (iter.hasNext()) {
 		qtractorCurveFile::Item *pCurveItem = iter.next();
-		if (pCurveItem->index == activateSubjectIndex()) {
-			pCurveItem->subject = activateSubject();
+		if ((iActivateSubjectIndex > 0 &&
+			 iActivateSubjectIndex == pCurveItem->index) ||
+			(pActivateSubject->name() == pCurveItem->name)) {
+			pCurveItem->subject = pActivateSubject;
+			setActivateSubjectIndex(0); // hack down!
+			iActivateSubjectIndex = 0;
 		} else {
 			qtractorPluginParam *pParam = NULL;
 			if (!pCurveItem->name.isEmpty())
@@ -1773,6 +1783,7 @@ bool qtractorPluginList::loadElement (
 			qtractorCurveFile cfile(qtractorPluginList::curveList());
 			QPoint posEditor;
 			QPoint posForm;
+			int iEditorType = -1;
 			const QString& sTypeHint = ePlugin.attribute("type");
 			qtractorPluginType::Hint typeHint
 				= qtractorPluginType::hintFromText(sTypeHint);
@@ -1841,6 +1852,9 @@ bool qtractorPluginList::loadElement (
 					posForm.setX(sxy.at(0).toInt());
 					posForm.setY(sxy.at(1).toInt());
 				}
+				else
+				if (eParam.tagName() == "editor-type")
+					iEditorType = eParam.text().toInt(); 
 			}
 			// Try to find some alternative, if it doesn't exist...
 			qtractorPlugin *pPlugin = NULL;
@@ -1878,6 +1892,8 @@ bool qtractorPluginList::loadElement (
 				pPlugin->setActivated(bActivated); // Later's better!
 				pPlugin->setEditorPos(posEditor);
 				pPlugin->setFormPos(posForm);
+				if (iEditorType >= 0)
+					pPlugin->setEditorType(iEditorType);
 			} else {
 				qtractorMessageList::append(
 					QObject::tr("%1(%2): %3 plugin not found.")
@@ -1962,10 +1978,6 @@ bool qtractorPluginList::saveElement ( qtractorDocument *pDocument,
 			QString::number(pPlugin->directAccessParamIndex()), &ePlugin);
 	//	pDocument->saveTextElement("values",
 	//		pPlugin->valueList().join(","), &ePlugin);
-		if (pPlugin->isActivateSubjectIndex()) {
-			pDocument->saveTextElement("activate-subject-index",
-				QString::number(pPlugin->activateSubjectIndex()), &ePlugin);
-		}
 		pDocument->saveTextElement("activated",
 			qtractorDocument::textFromBool(pPlugin->isActivated()), &ePlugin);
 		// Plugin configuration stuff (CLOB)...
@@ -1989,6 +2001,12 @@ bool qtractorPluginList::saveElement ( qtractorDocument *pDocument,
 				= pDocument->document()->createElement("curve-file");
 			pPlugin->saveCurveFile(pDocument, &eCurveFile, &cfile);
 			ePlugin.appendChild(eCurveFile);
+			const unsigned long iActivateSubjectIndex
+				= pPlugin->activateSubjectIndex();
+			if (iActivateSubjectIndex > 0) {
+				pDocument->saveTextElement("activate-subject-index",
+					QString::number(iActivateSubjectIndex), &ePlugin);
+			}
 		}
 		// Save editor position...
 		const QPoint& posEditor = pPlugin->editorPos();
@@ -2003,7 +2021,11 @@ bool qtractorPluginList::saveElement ( qtractorDocument *pDocument,
 				QString::number(posForm.x()) + ',' +
 				QString::number(posForm.y()), &ePlugin);
 		}
-
+		const int iEditorType = pPlugin->editorType();
+		if (iEditorType >= 0) {
+			pDocument->saveTextElement("editor-type",
+				QString::number(iEditorType), &ePlugin);
+		}
 		// Add this plugin...
 		pElement->appendChild(ePlugin);
 
