@@ -1,7 +1,7 @@
 // qtractorPlugin.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -378,9 +378,6 @@ public:
 	unsigned long activateSubjectIndex() const
 		{ return m_iActivateSubjectIndex; }
 
-	bool isActivateSubjectIndex() const
-		{ return int(m_iActivateSubjectIndex) > m_params.count(); }
-
 	// An accessible list of parameters.
 	typedef QMap<unsigned long, qtractorPluginParam *> Params;
 	const Params& params() const
@@ -398,8 +395,6 @@ public:
 			pParam->observer()->setLogarithmic(true);
 		m_params.insert(pParam->index(), pParam);
 		m_paramNames.insert(pParam->name(), pParam);
-		if (pParam->index() >= m_iActivateSubjectIndex)
-			m_iActivateSubjectIndex = pParam->index() + 1;
 	}
 
 	// Instance capped number of audio ports.
@@ -493,6 +488,12 @@ public:
 	// Move widget to alleged parent center or else...
 	void moveWidgetPos(QWidget *pWidget, const QPoint& wpos) const;
 
+	// Custom GUI editor type index preference.
+	void setEditorType(int iEditorType)
+		{ m_iEditorType = iEditorType; }
+	int editorType() const
+		{ return m_iEditorType; }
+
 	// An accessible list of observers.
 	const QList<qtractorPluginListItem *>& items() const
 		{ return m_items; }
@@ -713,6 +714,9 @@ private:
 	QString m_sEditorTitle;
 	QPoint  m_posEditor;
 
+	// Custom GUI editor type index preference.
+	int m_iEditorType;
+
 	// Plugin configuration (CLOB) stuff.
 	Configs m_configs;
 
