@@ -1,7 +1,7 @@
 // qtractorSession.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
 #include "qtractorTrack.h"
 #include "qtractorTimeScale.h"
 
+#include <QHash>
 
 // Forward declarations.
 class qtractorClip;
@@ -246,6 +247,7 @@ public:
 
 	// Playhead positioning.
 	void setPlayHead(unsigned long iPlayHead);
+	void setPlayHeadEx(unsigned long iPlayHead);
 	unsigned long playHead() const;
 
 	// Auto-backward play-head positioning.
@@ -282,9 +284,21 @@ public:
 	// Sanitize a given name.
 	static QString sanitize(const QString& s); 
 
+	// Provide an unique track-name if applicable,
+	// append an incremental numerical suffix...
+	QString uniqueTrackName(const QString& sTrackName) const;
+
+	void acquireTrackName(qtractorTrack *pTrack);
+	void releaseTrackName(qtractorTrack *pTrack);
+
+	// Transient file-name registry methods as far to
+	// avoid duplicates across load/save/record cycles...
+	void acquireFilePath(const QString& sFilename);
+	void releaseFilePath(const QString& sFilename);
+
 	// Create a brand new filename (absolute file path).
 	QString createFilePath(
-		const QString& sTrackName, const QString& sExt, int iClipNo = 0);
+		const QString& sBaseName, const QString& sExt);
 
 	// Consolidated session record state.
 	void setRecording(bool bRecording);
@@ -476,6 +490,12 @@ private:
 	// File registry.
 	qtractorFileList *m_pFiles;
 
+	// Transient file-name registry.
+	QStringList m_filePaths;
+
+	// Track-name registry.
+	QHash<QString, qtractorTrack *> m_trackNames;
+
 	// The pseudo-singleton instance.
 	static qtractorSession *g_pSession;
 };
