@@ -1,7 +1,7 @@
 // qtractorTrackForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -416,10 +416,20 @@ qtractorTrack::TrackType qtractorTrackForm::trackType (void) const
 // Accept settings (OK button slot).
 void qtractorTrackForm::accept (void)
 {
+	qtractorSession *pSession = qtractorSession::getInstance();
+	if (pSession == NULL)
+		return;
+
 	// Save options...
 	if (m_iDirtyCount > 0) {
+		// Make sure one has unque track names...
+		pSession->releaseTrackName(m_pTrack);
+		const QString& sTrackName
+			= pSession->uniqueTrackName(
+				m_ui.TrackNameTextEdit->toPlainText().trimmed());
+		pSession->acquireTrackName(m_pTrack);
 		// Make changes permanent...
-		m_props.trackName = m_ui.TrackNameTextEdit->toPlainText();
+		m_props.trackName = sTrackName;
 		m_props.trackType = trackType();
 		m_props.inputBusName  = m_ui.InputBusNameComboBox->currentText();
 		m_props.outputBusName = m_ui.OutputBusNameComboBox->currentText();
@@ -1147,14 +1157,17 @@ void qtractorTrackForm::trackIconClicked (void)
 	filters.append(tr("Image files (%1)").arg("*.png *.xpm *.jpg *.jpeg"));
 	filters.append(tr("All files (*.*)"));
 
-	const QString& sTitle  = tr("Track Icon") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = filters.join(";;");
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to open...
+	const QString& sTitle
+		= tr("Track Icon") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= filters.join(";;");
+
 	QFileDialog::Options options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to open...
 	sFilename = QFileDialog::getOpenFileName(this,
 		sTitle, sFilename, sFilter, NULL, options);
 #else
@@ -1163,9 +1176,7 @@ void qtractorTrackForm::trackIconClicked (void)
 	// Set proper open-file modes...
 	fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
 	fileDialog.setFileMode(QFileDialog::AnyFile);
-	qtractorOptions *pOptions = qtractorOptions::getInstance();
-	if (pOptions && pOptions->bDontUseNativeDialogs)
-		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
@@ -1421,9 +1432,16 @@ void qtractorTrackForm::progChanged (void)
 // Select custom track foreground color.
 void qtractorTrackForm::selectForegroundColor (void)
 {
+	const QString& sTitle
+		= tr("Foreground Color") + " - " QTRACTOR_TITLE;
+
+	QColorDialog::ColorDialogOptions options = 0;
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions && pOptions->bDontUseNativeDialogs)
+		options |= QColorDialog::DontUseNativeDialog;
+
 	const QColor& color = QColorDialog::getColor(
-		colorItem(m_ui.ForegroundColorComboBox), this,
-		tr("Foreground Color") + " - " QTRACTOR_TITLE);
+		colorItem(m_ui.ForegroundColorComboBox), this, sTitle, options);
 
 	if (color.isValid()) {
 		m_props.foreground = color;
@@ -1436,9 +1454,16 @@ void qtractorTrackForm::selectForegroundColor (void)
 // Select custom track background color.
 void qtractorTrackForm::selectBackgroundColor (void)
 {
+	const QString& sTitle
+		= tr("Background Color") + " - " QTRACTOR_TITLE;
+
+	QColorDialog::ColorDialogOptions options = 0;
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions && pOptions->bDontUseNativeDialogs)
+		options |= QColorDialog::DontUseNativeDialog;
+
 	const QColor& color = QColorDialog::getColor(
-		colorItem(m_ui.BackgroundColorComboBox), this,
-		tr("Background Color") + " - " QTRACTOR_TITLE);
+		colorItem(m_ui.BackgroundColorComboBox), this, sTitle, options);
 
 	if (color.isValid()) {
 		m_props.background = color;
