@@ -1,7 +1,7 @@
 // qtractorTracks.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1177,15 +1177,19 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 	if (pAudioBus == NULL)
 		return false;
 
-	const QString& sExt = qtractorAudioFileFactory::defaultExt();
-	const QString& sTitle  = tr("Merge/Export Audio Clip") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = tr("Audio files (*.%1)").arg(sExt); 
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to save...
+	const QString& sExt
+		= qtractorAudioFileFactory::defaultExt();
+	const QString& sTitle
+		= tr("Merge/Export Audio Clip") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= tr("Audio files (*.%1)").arg(sExt); 
+
 	QFileDialog::Options options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to save...
 	QString sFilename = QFileDialog::getSaveFileName(this, sTitle,
 		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, NULL, options);
 #else
@@ -1197,15 +1201,13 @@ bool qtractorTracks::mergeExportAudioClips ( qtractorClipCommand *pClipCommand )
 	fileDialog.setFileMode(QFileDialog::AnyFile);
 	fileDialog.setDefaultSuffix(sExt);
 	// Stuff sidebar...
-	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions) {
 		QList<QUrl> urls(fileDialog.sidebarUrls());
 		urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 		urls.append(QUrl::fromLocalFile(pOptions->sAudioDir));
 		fileDialog.setSidebarUrls(urls);
-		if (pOptions->bDontUseNativeDialogs)
-			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	}
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (!fileDialog.exec())
 		return false;
@@ -1443,14 +1445,17 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 
 	// Merge MIDI Clip filename requester...
 	const QString  sExt("mid");
-	const QString& sTitle  = tr("Merge/Export MIDI Clip") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt); 
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filename to save...
+	const QString& sTitle
+		= tr("Merge/Export MIDI Clip") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt); 
+
 	QFileDialog::Options options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filename to save...
 	QString sFilename = QFileDialog::getSaveFileName(this, sTitle,
 		pSession->createFilePath(pTrack->trackName(), sExt), sFilter, NULL, options);
 #else
@@ -1462,15 +1467,13 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 	fileDialog.setFileMode(QFileDialog::AnyFile);
 	fileDialog.setDefaultSuffix(sExt);
 	// Stuff sidebar...
-	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions) {
 		QList<QUrl> urls(fileDialog.sidebarUrls());
 		urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 		urls.append(QUrl::fromLocalFile(pOptions->sMidiDir));
 		fileDialog.setSidebarUrls(urls);
-		if (pOptions->bDontUseNativeDialogs)
-			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	}
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (!fileDialog.exec())
 		return false;
@@ -2541,7 +2544,8 @@ bool qtractorTracks::addTrack (void)
 	const int iTrack = pSession->tracks().count() + 1;
 	const QColor& color = qtractorTrack::trackColor(iTrack);
 	qtractorTrack *pTrack = new qtractorTrack(pSession);
-	pTrack->setTrackName(QString("Track %1").arg(iTrack));
+	pTrack->setTrackName(
+		pSession->uniqueTrackName(QString("Track %1").arg(iTrack)));
 	pTrack->setMidiChannel(pSession->midiTag() % 16);
 	pTrack->setBackground(color);
 	pTrack->setForeground(color.darker());
@@ -2676,18 +2680,8 @@ bool qtractorTracks::copyTrack ( qtractorTrack *pTrack )
 	qtractorTrack *pNewTrack = new qtractorTrack(pSession, pTrack->trackType());
 	pNewTrack->setProperties(pTrack->properties());
 	// Find an incremental/next track name...
-	QString sTrackName = pTrack->trackName();
-	QString sNewTrackName;
-	const QRegExp rxTrackNo("([0-9]+)$");
-	int iTrackNo = 0;
-	if (rxTrackNo.indexIn(sTrackName) >= 0) {
-		iTrackNo = rxTrackNo.cap(1).toInt();
-		sTrackName.remove(rxTrackNo);
-	}
-	else sTrackName += ' ';
-	do { sNewTrackName = sTrackName + QString::number(++iTrackNo); }
-	while (pSession->findTrack(sNewTrackName));
-	pNewTrack->setTrackName(sNewTrackName);
+	pNewTrack->setTrackName(
+		pSession->uniqueTrackName(pTrack->trackName()));
 	pNewTrack->setBackground(color);
 	pNewTrack->setForeground(color.darker());
 	pNewTrack->setZoomHeight(pTrack->zoomHeight());
@@ -2759,8 +2753,10 @@ bool qtractorTracks::addAudioTracks ( const QStringList& files,
 		// Time to add the new track/clip into session;
 		// actuallly, this is when the given audio file gets open...
 		pTrack->addClip(pAudioClip);
-		if (iTrackClip == 0)
-			pTrack->setTrackName(pAudioClip->clipName());
+		if (iTrackClip == 0) {
+			pTrack->setTrackName(
+				pSession->uniqueTrackName(pAudioClip->clipName()));
+		}
 		++iTrackClip;
 		// Add the new track to composite command...
 		if (bDropSpan)
@@ -2873,7 +2869,8 @@ bool qtractorTracks::addMidiTracks ( const QStringList& files,
 			// Time to check whether there is actual data on track...
 			if (pMidiClip->clipLength() > 0) {
 				// Add the new track to composite command...
-				pTrack->setTrackName(pMidiClip->clipName());
+				pTrack->setTrackName(
+					pSession->uniqueTrackName(pMidiClip->clipName()));
 				pTrack->setMidiChannel(pMidiClip->channel());
 				pImportTrackCommand->addTrack(pTrack);
 				++iUpdate;
@@ -2949,7 +2946,8 @@ bool qtractorTracks::addMidiTrackChannel ( const QString& sPath,
 	pMidiClip->setClipStart(iClipStart);
 	// Time to add the new track/clip into session...
 	pTrack->addClip(pMidiClip);
-	pTrack->setTrackName(pMidiClip->clipName());
+	pTrack->setTrackName(
+		pSession->uniqueTrackName(pMidiClip->clipName()));
 	pTrack->setMidiChannel(pMidiClip->channel());
 	// Add the new track to composite command...
 	pImportTrackCommand->addTrack(pTrack);
